@@ -10,8 +10,8 @@ export JIGSAW_HOME
 LD_LIBRARY_PATH=${JIGSAW_HOME}/lib
 export LD_LIBRARY_PATH
 
-CLASSPATH=${JIGSAW_HOME}/classes/jigsaw.zip:${JIGSAW_HOME}/classes/servlet.jar:.
+CLASSPATH=${JIGSAW_HOME}/classes/jigsaw.jar:${JIGSAW_HOME}/classes/sax.jar:${JIGSAW_HOME}/classes/xp.jar:${JIGSAW_HOME}/classes/servlet.jar
 export CLASSPATH
 
-java -Xms8m -Xmx128m org.w3c.jigsaw.Main -root ${JIGSAW_HOME}/Jigsaw $* 
+java -Xms16m -Xmx128m org.w3c.jigsaw.Main -root ${JIGSAW_HOME}/Jigsaw $* 
 # done.
