@@ -1,5 +1,5 @@
 // AdminServer.java
-// $Id: AdminServer.java,v 1.26.2.2 2000/07/04 08:54:26 ylafon Exp $
+// $Id: AdminServer.java,v 1.28 2000/03/06 10:07:30 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -15,10 +15,12 @@ import org.w3c.www.mime.*;
 import org.w3c.www.http.*;
 import org.w3c.jigsaw.daemon.*;
 import org.w3c.jigsaw.http.*;
+import org.w3c.jigsaw.filters.TEFilter;
 import org.w3c.jigsaw.auth.*;
 
 import org.w3c.tools.resources.ProtocolException;
 import org.w3c.tools.resources.ResourceException;
+import org.w3c.tools.resources.serialization.Serializer;
 
 class ServerHandlerManagerResource extends AbstractContainer {
     ServerHandlerManager shm = null;
@@ -82,6 +84,8 @@ public class AdminServer extends httpd {
     protected ControlResource      controlConfig    = null;
     protected ResourceReference    rr_controlConfig = null;
     protected GenericAuthFilter    auth             = null;
+    protected Serializer           serializer       = null;
+    protected ResourceFilter       filters[]        = null;
 
     /**
      * The realm catalog
@@ -104,7 +108,7 @@ public class AdminServer extends httpd {
     } 
   
     protected String getBanner() {
-	return "JigAdmin[2.0.5]";
+	return "JigAdmin[2.1.1]";
     } 
 
     public ResourceReference getConfigResource() {
@@ -139,68 +143,23 @@ public class AdminServer extends httpd {
     {
 	// Dump the root resource:
 	ByteArrayOutputStream bout = new ByteArrayOutputStream();
-	DataOutputStream      out  = new DataOutputStream(bout);
 	try {
-	    writer.writeResource(out, root);
-	    out.close();
+	    writer.writeResource(root, bout);
 	} catch (IOException ex) {
 	    System.out.println(ex.getMessage());
 	    ex.printStackTrace();
 	    throw new HTTPException("unable to dump root");
+	} catch (Exception ex) {
+	    System.out.println(ex.getMessage());
+	    ex.printStackTrace();
+	    throw new HTTPException("unable to dump root: "+ex.getMessage());
 	}
 	byte bits[] = bout.toByteArray();
 	// Setup the reply:
 	Reply reply = request.makeReply(HTTP.OK);
 	reply.setStream(new ByteArrayInputStream(bits));
 	reply.setContentLength(bits.length);
-	reply.setContentType(ResourceBroker.conftype);
-	return reply;
-    }
-
-    /**
-     * List the attributes.
-     * @param request The incomming request.
-     * @exception org.w3c.tools.resources.ProtocolException if a protocol 
-     * error occurs.
-     */
-    public Reply remoteListAttributes(Request request) 
-	throws ProtocolException
-    {
-	// Get the name of the class whose attributes are being fetched:
-	LookupState ls = null;
-	try {
-	    ls = new LookupState(request);
-	} catch (org.w3c.tools.resources.ProtocolException ex) {
-	    throw new HTTPException(ex);
-	}
-	String      cs = ls.getNextComponent();
-	// Get this class attributes:
-	Class c = null;
-	try {
-	    c = Class.forName(cs);
-	} catch (Exception ex) {
-	    ex.printStackTrace();
-	    return null;
-	}
-	// Get the atributes:
-	Attribute attrs[] = AttributeRegistry.getClassAttributes(c);
-	byte      bits[]  = null;
-	try {
-	    // Dump them into a byte array:
-	    ByteArrayOutputStream bout = new ByteArrayOutputStream();
-	    DataOutputStream      out  = new DataOutputStream(bout);
-	    writer.writeAttributes(out, attrs);
-	    out.close();
-	    bits = bout.toByteArray();
-	} catch (Exception ex) {
-	    ex.printStackTrace();
-	    throw new HTTPException("couldn't dump attributes");
-	}
-	// Emit the appropriate HTP reply:
-	Reply reply = request.makeReply(HTTP.OK);
-	reply.setContentType(ResourceBroker.conftype);
-	reply.setContentLength(bits.length);
-	reply.setStream(new ByteArrayInputStream(bits));
+	reply.setContentType(AdminContext.conftype);
 	return reply;
     }
 
@@ -214,20 +173,33 @@ public class AdminServer extends httpd {
 	throws ProtocolException, ResourceException
     {
 	Request request = (Request) req;
+	Reply   reply   = null;
 	auth.authenticate(request);
+	//ingoing filters
+	for (int i = 0 ; i < filters.length ; i++) {
+	    reply = (Reply) filters[i].ingoingFilter(req);
+	    if (reply != null)
+		return reply;
+	}
 	// Maybe that's one of the methods we handle straight ?
 	String mth = request.getMethod();
 	if ( mth.equals("LOAD-ROOT") ) {
-	    return remoteLoadRoot(request);
-	} else if (mth.equals("LIST-ATTRIBUTES")) {
-	    return remoteListAttributes(request);
+	    reply = remoteLoadRoot(request);
+	} else {
+	    // Ok, that's targeted toward a specific target resource:
+	    try {
+		reply = (Reply)broker.perform(request);
+	    } catch (org.w3c.tools.resources.ProtocolException ex) {
+		throw new HTTPException(ex);
+	    }
 	}
-	// Ok, that's targeted toward a specific target resource:
-	try {
-	    return (Reply)broker.perform(request);
-	} catch (org.w3c.tools.resources.ProtocolException ex) {
-	    throw new HTTPException(ex);
+	//outgoing filters
+	for (int i = filters.length-1 ; i > -1 ; i--) {
+	    Reply rep = (Reply) filters[i].outgoingFilter(req, reply);
+	    if (rep != null)
+		return rep;
 	}
+	return reply;
     }
     
     public FramedResource getRoot() {
@@ -248,6 +220,20 @@ public class AdminServer extends httpd {
 	auth.setValue("realm", "JigAdmin");
     }
 
+    protected void addFilter(ResourceFilter filter, Hashtable defs) {
+	filter.initialize(defs);
+	if (filters == null) {
+	    filters = new ResourceFilter[1];
+	    filters[0] = filter;
+	} else {
+	    int len = filters.length;
+	    ResourceFilter nfilters[] = new ResourceFilter[len+1];
+	    System.arraycopy(filters, 0, nfilters, 0, len);
+	    nfilters[len] = filter;
+	    filters = nfilters;
+	}
+    }
+
     /**
      * Initialize the Server
      * @exception ServerHandlerInitException if it can't be initialized
@@ -259,12 +245,20 @@ public class AdminServer extends httpd {
     {
 	super.initialize(shm, identifier, props);
 	// Create our only resource:
-	this.shm = shm;
-	writer   = new AdminWriter(this);
-	broker   = new ResourceBroker(shm, this, writer);
-	root     = new ServerHandlerManagerResource(this, shm);
-	auth     = new GenericAuthFilter();
+	this.shm   = shm;
+	writer     = new AdminWriter();
+	broker     = new ResourceBroker(shm, this, writer);
+	root       = new ServerHandlerManagerResource(this, shm);
+	auth       = new GenericAuthFilter();
+	serializer = 
+	    new org.w3c.tools.resources.serialization.xml.XMLSerializer();
 	initializeAuth();
+	TEFilter tefilter = new TEFilter();
+	Hashtable defs = new Hashtable(2);
+	defs.put("identifier", "tefilter");
+	String mimes[] = { AdminContext.conftype.toString() };
+	defs.put("mime-types", mimes );
+	addFilter(tefilter, defs);
     }
 
     public AdminServer() {
