@@ -1,11 +1,13 @@
 // RemoteResource.java
-// $Id: RemoteResource.java,v 1.10.4.1 2000/02/18 15:14:05 bmahe Exp $
+// $Id: RemoteResource.java,v 1.12 2000/02/18 15:12:34 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.admin;
 
 import java.net.*;
+import org.w3c.tools.resources.serialization.AttributeDescription;
+
 /**
  * The client side view of a server-side resource.
  * The whole servers state are exported through resources, which allows
@@ -41,6 +43,7 @@ public interface RemoteResource {
 
     /**
      * Reindex the resource's children if this resource is a DirectoryResource.
+     * @param rec recursivly?
      * @exception RemoteAccessException If it's not a DirectoryResource
      */
     public void reindex(boolean rec)
@@ -58,7 +61,7 @@ public interface RemoteResource {
      * @exception RemoteAccessException If somenetwork failure occured.
      */
 
-    public org.w3c.tools.resources.Attribute[] getAttributes()
+    public AttributeDescription[] getAttributes()
 	throws RemoteAccessException;
 
     /**
