@@ -1,5 +1,5 @@
 // RealmsCatalog.java
-// $Id: RealmsCatalog.java,v 1.13.4.1 2000/01/21 13:19:56 bmahe Exp $
+// $Id: RealmsCatalog.java,v 1.14 2000/01/21 13:18:38 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -38,6 +38,7 @@ public class RealmsCatalog extends ExternalContainer {
      */
 
     public synchronized void registerRealm(AuthRealm realm) {
+	System.out.println("register realm : "+realm.getIdentifier());
 	addResource(realm, null) ;
     }
    
@@ -50,11 +51,12 @@ public class RealmsCatalog extends ExternalContainer {
 				 Resource resource,
 				 Hashtable defs) 
     {
-	if ( resource instanceof AuthRealm)
+	if ( resource instanceof AuthRealm) {
 	    registerRealm(
 			 AuthRealm.makeRealm(resource,
 					     new ResourceContext(getContext()),
 					     name ));
+	}
     }
     
     /**
