@@ -1,5 +1,5 @@
 // EncodingAttribute.java
-// $Id: EncodingAttribute.java,v 1.1 1998/01/22 13:58:57 bmahe Exp $
+// $Id: EncodingAttribute.java,v 1.2 1999/09/07 13:28:52 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -14,4 +14,8 @@ public class EncodingAttribute extends StringAttribute {
 	this.type = "java.lang.String";
     }
 
+    public EncodingAttribute() {
+	super() ;
+    }
+
 }
