@@ -1,5 +1,5 @@
 // JpegComFrame.java
-// $Id: JpegComFrame.java,v 1.1.2.11 2000/03/09 21:11:10 ylafon Exp $
+// $Id: JpegComFrame.java,v 1.17 2000/02/16 16:10:23 ylafon Exp $
 // (c) COPYRIGHT MIT, INRIA and Keio, 1999.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -8,6 +8,7 @@ package org.w3c.jigsaw.frames;
 import java.util.*;
 import java.io.*;
 import java.net.URLEncoder;
+import java.net.URLDecoder;
 
 import org.w3c.www.mime.*;
 import org.w3c.util.*;
@@ -316,15 +317,24 @@ public class JpegComFrame extends HTTPFrame {
 	Reply reply = null;
 	fresource.checkContent();
 	updateCachedHeaders();
-	// hack, if ;text/html is there,
+	// hack, if ?text/html is there, (well text%2Frdf)
 	// it will be added at first place of the accept 
+	String query = request.getQueryString();
 	String param = null;
 	String sfile = request.getURL().getFile();
 	int pos = sfile.indexOf(';');
 	if (pos != -1) {
 	    param = (String) request.getState("type");
 	}
-	if (param != null) {
+	if ((query != null) || (param != null)) {
+	    String dquery = null;
+	    if (param != null) {
+		dquery = param;
+	    } else {
+		try {
+		    dquery = URLDecoder.decode(query);
+		} catch (Exception ex) {};
+	    }
 	    HttpAccept acc[] = request.getAccept();
 	    HttpAccept newacc[] = null;
 	    if (acc != null) {
@@ -334,7 +344,7 @@ public class JpegComFrame extends HTTPFrame {
 		newacc = new HttpAccept[1];
 	    }
 	    try {
-		newacc[0] = HttpFactory.makeAccept(new MimeType(param), 1.1);
+		newacc[0] = HttpFactory.makeAccept(new MimeType(dquery), 1.1);
 		request.setAccept(newacc);
 	    } catch (MimeTypeFormatException ex) {
 		// not a valid mime type... maybe something else, do not care
@@ -405,13 +415,22 @@ public class JpegComFrame extends HTTPFrame {
 	File file = fresource.getFile() ;
 	fresource.checkContent();
 	updateCachedHeaders();
+	String query = request.getQueryString();
 	String param = null;
 	String sfile = request.getURL().getFile();
 	int pos = sfile.indexOf(';');
 	if (pos != -1) {
 	    param = (String) request.getState("type");
 	}
-	if (param != null) {
+	if ((query != null) || (param != null)) {
+	    String dquery = null;
+	    if (param != null) {
+		dquery = param;
+	    } else {
+		try {
+		    dquery = URLDecoder.decode(query);
+		} catch (Exception ex) {};
+	    }
 	    HttpAccept acc[] = request.getAccept();
 	    HttpAccept newacc[] = null;
 	    if (acc != null) {
@@ -421,7 +440,7 @@ public class JpegComFrame extends HTTPFrame {
 		newacc = new HttpAccept[1];
 	    }
 	    try {
-		newacc[0] = HttpFactory.makeAccept(new MimeType(param), 1.1);
+		newacc[0] = HttpFactory.makeAccept(new MimeType(dquery), 1.1);
 		request.setAccept(newacc);
 	    } catch (MimeTypeFormatException ex) {
 		// not a valid mime type... maybe something else, do not care
