@@ -1,5 +1,5 @@
 // ProxyFrame.java
-// $Id: ProxyFrame.java,v 1.9.4.4 2000/03/01 10:15:50 ylafon Exp $
+// $Id: ProxyFrame.java,v 1.16 2000/03/01 10:10:42 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1998.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -73,7 +73,7 @@ class Stats extends HTTPFrame {
 	
 	if ( c == 0 )
 	    c = 1;
-	g.meta("Refresh", "30");
+	g.addMeta("Refresh", "30");
 	proxy.addStyleSheet(g);
 	g.append("<h1>Proxy statistics</h1>");
 	g.append("<p>The proxy was last started at: <em>"
@@ -335,6 +335,7 @@ public class ProxyFrame extends ForwardFrame {
 
 	Request request = (Request) ls.getRequest();
 	URL     requrl  = request.getURL() ;
+
 	if ((url != null)
 	    && ((requrl.getPort() == url.getPort()) || 
 		(requrl.getPort() * url.getPort() == -80))
