@@ -1,5 +1,5 @@
 // JigsawServletContext.java
-// $Id: JigsawServletContext.java,v 1.24.4.6 2000/03/14 17:50:50 bmahe Exp $
+// $Id: JigsawServletContext.java,v 1.26 2000/03/03 16:04:07 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1998.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -21,7 +21,7 @@ import org.w3c.jigsaw.resources.VirtualHostResource;
 import org.w3c.jigsaw.http.httpd;
 
 /**
- * @version $Revision: 1.24.4.6 $
+ * @version $Revision: 1.26 $
  * @author  Benot Mah (bmahe@w3.org)
  */
 public class JigsawServletContext extends StructureChangedAdapter
@@ -283,94 +283,22 @@ public class JigsawServletContext extends StructureChangedAdapter
 
     /**
      * ServletContext implementation - Translate a piece of path.
-     * @param path the virtual path to translate
-     * @param rr_root the Root ResourceReference
-     * @param rr the target ResourceReference
-     * @return the real path
      */
-    protected static String getRealPath(String path, 
-					ResourceReference rr_root,
-					ResourceReference rr) 
-    {
-	ResourceReference local_root = getLocalRoot(rr_root, rr);
-	try {
-	    FramedResource root = (FramedResource)local_root.lock();
-	    LookupState    ls   = new LookupState(path);
-	    LookupResult   lr   = new LookupResult(local_root);
-	    if (root.lookup(ls,lr)) {
-		ResourceReference  target = lr.getTarget();
-		if (target != null) {
-		    try {
-			FramedResource res = (FramedResource)target.lock();
-			if (res instanceof FileResource) {
-			    File file = ((FileResource)res).getFile();
-			    return file.getAbsolutePath();
-			} else if (res instanceof DirectoryResource) {
-			    DirectoryResource dir = (DirectoryResource) res;
-			    return dir.getDirectory().getAbsolutePath();
-			    //return getFilePath(dir);
-			}
-		    } finally {
-			target.unlock();
-		    }
-		}
-	    }
-	    return null;
-	} catch (InvalidResourceException ex) {
-	    return null;
-	} catch (org.w3c.tools.resources.ProtocolException pex) {
-	    return null;
-	} finally {
-	    local_root.unlock();
-	}
-    }
 
-    /**
-     * ServletContext implementation - Translate a piece of path.
-     * @param path the virtual path to translate
-     * @return the real path
-     */
     public String getRealPath(String path) {
-	ResourceReference rr_root = ((httpd) getServer()).getRootReference();
-	return getRealPath(path, rr_root, reference);
-    }
-
-    protected static String getFilePath(DirectoryResource dir) {
-	HTTPFrame frame = 
-	    (HTTPFrame)dir.getFrame("org.w3c.jigsaw.frames.HTTPFrame");
-	String indexes[] = frame.getIndexes();
-	if (indexes != null) {
-	    for (int i = 0 ; i < indexes.length ; i++) {
-		String index = indexes[i];
-		if ( index != null && index.length() > 0) {
-		    ResourceReference rr = dir.lookup(index);
-		    if (rr != null) {
-			try {
-			    FramedResource ri = (FramedResource) rr.lock();
-			    if (ri instanceof FileResource) {
-				FileResource fr = (FileResource) ri;
-				File file = fr.getFile();
-				return file.getAbsolutePath();
-			    } else {
-				// we don't know 
-				return null;
-			    }
-			} catch (InvalidResourceException ex) {
-			} finally {
-			    rr.unlock();
-			}
-		    }
-		}
-	    }
-	    return dir.getDirectory().getAbsolutePath();
-	} else {
-	    return dir.getDirectory().getAbsolutePath();
+	httpd             server  = (httpd)getServer();
+	ResourceReference rr_root = server.getRootReference();
+	File              dir     = getRootDirectory(rr_root,
+						     reference);
+	if (dir == null) {
+	    String message = "Error: unable to compute root directory";
+	    throw new RuntimeException(message);
 	}
+	return new File(dir, path).getAbsolutePath();
     }
 
-    protected static ResourceReference getLocalRoot(ResourceReference rr_root,
-						    ResourceReference ref) 
-    {
+    protected static File getRootDirectory(ResourceReference rr_root,
+					   ResourceReference ref) {
 	try {
 	    FramedResource root = (FramedResource)rr_root.lock();
 	    if (root instanceof VirtualHostResource) {
@@ -387,7 +315,7 @@ public class JigsawServletContext extends StructureChangedAdapter
 			rr = ref;
 		    }
 		} catch (InvalidResourceException ex) {
-		    return rr_root;
+		    return null;
 		} finally {
 		    ref.unlock();
 		}
@@ -397,37 +325,46 @@ public class JigsawServletContext extends StructureChangedAdapter
 			res = (FramedResource)rr.lock();
 			rrp = res.getParent();
 			if ((rrp == rr_root) || (rrp == null)) {
-			    return getLocalRoot(rr, ref);
+			    if (res.definesAttribute("directory")) {
+				return (File)res.getValue("directory", null);
+			    } else {
+				// root doesn't define directory attribute
+				return lookupLocalRoot(res, ref);
+			    }
 			}
 		    } catch (InvalidResourceException ex) {
-			return rr_root;
+			return null;
 		    } finally {
 			rr.unlock();
 		    }
 		    rr = rrp;
 		}
+	    } else if (root.definesAttribute("directory")) {
+		return (File)root.getValue("directory", null);
 	    } else {
-		try {
-		    FramedResource res = (FramedResource)rr_root.lock();
-		    ForwardFrame   ffr = (ForwardFrame)
-			res.getFrame("org.w3c.jigsaw.proxy.ForwardFrame");
-		    if (ffr == null) {
-			return rr_root;
-		    } else {
-			ResourceReference rr = ffr.getLocalRootResource();
-			return getLocalRoot(rr, ref);
-		    }
-		} catch (InvalidResourceException ex) {
-		    return rr_root;
-		}
+		// root doesn't define directory attribute
+		return lookupLocalRoot(root, ref);
 	    }
 	} catch (InvalidResourceException ex) {
-	    return rr_root;
+	    return null;
 	} finally {
 	    rr_root.unlock();
 	}
     }
 
+    protected static File lookupLocalRoot(FramedResource res,
+					  ResourceReference ref) {
+	// the only solution, we have a Forward frame
+	ForwardFrame ffr = (ForwardFrame)
+	    res.getFrame("org.w3c.jigsaw.proxy.ForwardFrame");
+	if (ffr == null) {
+	    return null;
+	} else {
+	    ResourceReference rr = ffr.getLocalRootResource();
+	    return getRootDirectory(rr, ref);
+	}
+    }
+
     /**
      * ServletContext implementation - Get server informations.
      */
@@ -561,8 +498,7 @@ public class JigsawServletContext extends StructureChangedAdapter
      */
     public RequestDispatcher getRequestDispatcher(String urlpath) {
 	return JigsawRequestDispatcher.getRequestDispatcher(urlpath, 
-							   (httpd)getServer(),
-							    reference);
+							   (httpd)getServer());
     }
 
     /**
@@ -647,22 +583,41 @@ public class JigsawServletContext extends StructureChangedAdapter
     public URL getResource(String path) 
 	throws MalformedURLException
     {
-	String realpath = getRealPath(path);
-	if (realpath != null) {
-	    File file = new File(realpath);
-	    if (file.exists()) {
-		return new URL("file", "", file.getAbsolutePath());
-	    } else {
-		return null;
-	    }
-	} else {
-	    // it could be a virtual resource
-	    // check that it exists (on server)
-	    // FIXME (Virtual host)
-	    return null;
+	httpd             server  = (httpd)getServer();
+	ResourceReference rr_root = server.getRootReference();
+	File              dir     = getRootDirectory(rr_root,
+						     reference);
+	if (dir == null) {
+	    String message = "Error: unable to compute root directory";
+	    throw new RuntimeException(message);
 	}
+	File file = new File(dir, path);
+	if (file.exists()) {
+	    return new URL("file", "", file.getAbsolutePath());
+	}
+	return null;
     }
 
+//     public URL getResource(String path) 
+// 	throws MalformedURLException
+//     {
+// 	if (path.length() > 0 && path.charAt(0) == '/')
+// 	    path = path.substring(1);
+// 	if (File.separatorChar != '/')
+// 	    path.replace('/', File.separatorChar);
+// 	//String dir = getServletDirectory().getAbsolutePath();
+// 	String dir = getServletDirectory().getAbsolutePath();
+// 	File file = new File(dir, path);
+// 	if (! file.exists())
+// 	    return null;
+// 	String url = file.getAbsolutePath();
+// 	if (File.separatorChar != '/')
+// 	    url = url.replace(File.separatorChar, '/');
+// 	if (url.length() > 0 && url.charAt(0) != '/')
+// 	    url = '/' + url;
+// 	return new URL("file", "", url);
+//     }
+
     public InputStream getResourceAsStream(String path) {
 	try {
 	    URL resource = getResource(path);
