@@ -1,5 +1,5 @@
 // ServletPropertiesReader.java
-// $Id: ServletPropertiesReader.java,v 1.1.2.6 2000/06/22 13:53:31 bmahe Exp $
+// $Id: ServletPropertiesReader.java,v 1.6 2000/03/03 16:04:07 bmahe Exp $
 // (c) COPYRIGHT MIT, INRIA and Keio, 1999.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -29,7 +29,7 @@ import org.w3c.tools.resources.LookupState;
 import org.w3c.tools.resources.LookupResult;
 
 /**
- * @version $Revision: 1.1.2.6 $
+ * @version $Revision: 1.6 $
  * @author  Benot Mah (bmahe@w3.org)
  */
 public class ServletPropertiesReader implements httpdPreloadInterface {
@@ -131,23 +131,15 @@ public class ServletPropertiesReader implements httpdPreloadInterface {
      * @return a ResourceReference
      */
     protected ResourceReference getServletDirectoryReference(httpd server) {
-	ResourceReference rr = server.getEditRoot(); 
+	FramedResource root = server.getRoot();
 	try {
-	    FramedResource root = (FramedResource) rr.lock();
-	    try {
-		LookupState  ls = new LookupState(SERVLET_BASE_P);
-		LookupResult lr = 
-		    new LookupResult(root.getResourceReference());
-		root.lookup(ls, lr);
-		return lr.getTarget();
-	    } catch (ProtocolException ex) {
-		ex.printStackTrace();
-		return null;
-	    }
-	} catch (InvalidResourceException ex) {
+	    LookupState  ls = new LookupState(SERVLET_BASE_P);
+	    LookupResult lr = new LookupResult(root.getResourceReference());
+	    root.lookup(ls, lr);
+	    return lr.getTarget();
+	} catch (ProtocolException ex) {
+	    ex.printStackTrace();
 	    return null;
-	} finally {
-	    rr.unlock();
 	}
     }
 
@@ -162,42 +154,34 @@ public class ServletPropertiesReader implements httpdPreloadInterface {
     {
 	String uri  = SERVLET_BASE_P+"/"+name;
 	// internal lookup
-	ResourceReference rr = server.getEditRoot();
+	FramedResource root = server.getRoot();
 	try {
-	    FramedResource root = (FramedResource) rr.lock();
-	    try {
-		DirectoryResource parent = (DirectoryResource) sdir.lock();
-		LookupState  ls = new LookupState(uri);
-		LookupResult lr = 
-		    new LookupResult(root.getResourceReference());
-		root.lookup(ls, lr);
-		ResourceReference target = lr.getTarget();
-		if (target != null) {
-		    try {
-			ServletWrapper wrapper = 
-			    (ServletWrapper) target.lock();
-			initialize(name, wrapper, parent);
-		    } finally {
-			target.unlock();
-		    }
-		} else { // doesn't exists, so create it...
-		    initialize(name, null, parent);
+	    DirectoryResource parent = (DirectoryResource) sdir.lock();
+	    LookupState  ls = new LookupState(uri);
+	    LookupResult lr = new LookupResult(root.getResourceReference());
+	    root.lookup(ls, lr);
+	    ResourceReference target = lr.getTarget();
+	    if (target != null) {
+		try {
+		    ServletWrapper wrapper = 
+			(ServletWrapper) target.lock();
+		    initialize(name, wrapper, parent);
+		} finally {
+		    target.unlock();
 		}
-	    } catch (ProtocolException pex) {
-		pex.printStackTrace();
-	    } catch (InvalidResourceException ex) {
-		ex.printStackTrace();
-	    } catch (MultipleLockException mlex) {
-		mlex.printStackTrace();
-	    } catch (ClassCastException ccex) {
-		ccex.printStackTrace();
-	    } finally {
-		sdir.unlock();
+	    } else { // doesn't exists, so create it...
+		initialize(name, null, parent);
 	    }
+	} catch (ProtocolException pex) {
+	    pex.printStackTrace();
 	} catch (InvalidResourceException ex) {
-	    // nothing to do :(
+	    ex.printStackTrace();
+	} catch (MultipleLockException mlex) {
+	    mlex.printStackTrace();
+	} catch (ClassCastException ccex) {
+	    ccex.printStackTrace();
 	} finally {
-	    rr.unlock();
+	    sdir.unlock();
 	}
     }
 
