@@ -1,5 +1,5 @@
 // Ssiframe.java
-// $Id: SSIFrame.java,v 1.11.4.1 2000/03/10 09:31:47 ylafon Exp $
+// $Id: SSIFrame.java,v 1.11 1999/07/15 15:10:55 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -635,7 +635,7 @@ public class SSIFrame extends HTTPFrame {
 	char ch ;
 	for(int i=0;i<max;i++) {
 	    ch = (char) unparsed[start+i];
-	    if(Character.isWhitespace(ch)) break ;
+	    if(Character.isSpace(ch)) break ;
 	    cmdBuf.append(ch) ;
 	}
 	return cmdBuf.length() == 0? null : cmdBuf.toString() ;
