@@ -1,5 +1,5 @@
 // Base64Decoder.java
-// $Id: Base64Decoder.java,v 1.3.4.2 2000/06/08 16:43:43 ylafon Exp $
+// $Id: Base64Decoder.java,v 1.4 1999/11/25 18:40:44 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -40,7 +40,7 @@ public class Base64Decoder {
     private void printHex (String s) {
 	byte bytes[] ;
 	try {
-	    bytes = s.getBytes ("ISO-8859-1");
+	    bytes = s.getBytes ("ISO8859_1");
 	} catch (UnsupportedEncodingException ex) {
 	    throw new RuntimeException(this.getClass().getName() + 
 				       "[printHex] Unable to convert" +
@@ -156,7 +156,7 @@ public class Base64Decoder {
 	}
 	String s;
 	try {
-	    s = ((ByteArrayOutputStream) out).toString("ISO-8859-1") ;
+	    s = ((ByteArrayOutputStream) out).toString("ISO8859_1") ;
 	} catch (UnsupportedEncodingException ex) {
 	    throw new RuntimeException(this.getClass().getName() + 
 				       "[processString] Unable to convert" +
@@ -173,7 +173,7 @@ public class Base64Decoder {
     public Base64Decoder (String input) {
 	byte bytes[] ;
 	try {
-	    bytes = input.getBytes ("ISO-8859-1");
+	    bytes = input.getBytes ("ISO8859_1");
 	} catch (UnsupportedEncodingException ex) {
 	    throw new RuntimeException(this.getClass().getName() + 
 				       "[Constructor] Unable to convert" +
