@@ -1,5 +1,5 @@
 // Base64Encoder.java
-// $Id: Base64Encoder.java,v 1.5.4.2 2000/06/08 16:44:35 ylafon Exp $
+// $Id: Base64Encoder.java,v 1.6 1999/11/25 18:40:44 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -179,7 +179,7 @@ public class Base64Encoder {
     public Base64Encoder (String input) {
 	byte bytes[] ;
 	try {
-	    bytes = input.getBytes ("ISO-8859-1");
+	    bytes = input.getBytes ("ISO8859_1");
 	} catch (UnsupportedEncodingException ex) {
 	    throw new RuntimeException(this.getClass().getName() + 
 				       "[Constructor] Unable to convert" +
