@@ -1,5 +1,5 @@
 // JpegHeaders.java
-// $Id: JpegHeaders.java,v 1.1.2.6 2000/05/31 16:28:23 ylafon Exp $
+// $Id: JpegHeaders.java,v 1.4 1999/11/29 10:41:09 ylafon Exp $
 // (c) COPYRIGHT MIT, INRIA and Keio, 1999.
 // Please first read the full copyright statement in file COPYRIGHT.html
  
@@ -9,7 +9,7 @@ import java.io.*;
 import java.util.Vector;
 
 /**
- * @version $Revision: 1.1.2.6 $
+ * @version $Revision: 1.4 $
  * @author  Benot Mah (bmahe@w3.org)
  * jpeg reading code adapted from rdjpgcom from The Independent JPEG Group 
  */
@@ -32,7 +32,7 @@ public class JpegHeaders implements Jpeg {
 	return comments;
     }
 
-    public String[] getAPPComments() {
+    public String[] getAPP12Comments() {
 	if (appcomments == null) {
 	    appcomments = new String[vacom.size()];
 	    vacom.copyInto(appcomments);
@@ -70,22 +70,20 @@ public class JpegHeaders implements Jpeg {
 		skipVariable();
 		break;
 	    case M_SOS:	 /* stop before hitting compressed data */
-		skipVariable();
 		return marker;
 	    case M_EOI:	 /* in case it's a tables-only JPEG stream */
 		return marker;
 	    case M_COM:
 		vcom.addElement(processComment());
 		break;
-	    case M_APP1:
 	    case M_APP12:
-		// Some digital camera makers put useful textual
-		// information into APP1 andAPP12 markers, so we print
-		// those out too when in -verbose mode.
+		/* Some digital camera makers put useful textual */
+		/* information into APP12 markers, so we print   */
+		/* those out too when in -verbose mode.          */
 		vacom.addElement(processComment());
 		break;
-	    default:	          // Anything else just gets skipped
-		skipVariable();  // we assume it has a parameter count...
+	    default:	          /* Anything else just gets skipped */
+		skipVariable();  /* we assume it has a parameter count... */
 		break;
 	    }
 	}
@@ -114,7 +112,7 @@ public class JpegHeaders implements Jpeg {
 	    pos += got;
 	    length -= got;
 	}
-	return new String(comment, "ISO-8859-1");
+	return new String(comment, "UTF8");
     }
 
     protected int read2bytes() 
@@ -193,9 +191,6 @@ public class JpegHeaders implements Jpeg {
 	} catch (Exception ex) {
 	    ex.printStackTrace();
 	}
-	try {
-	    in.close();
-	} catch (Exception ex) {};
     }
 
     /**
@@ -219,9 +214,9 @@ public class JpegHeaders implements Jpeg {
 		for (int i = 0 ; i < comments.length ; i++) 
 		    System.out.println(comments[i]);
 	    }
-	    comments = headers.getAPPComments();
+	    comments = headers.getAPP12Comments();
 	    if (comments != null) {
-		System.out.println("APP Comments: ");
+		System.out.println("APP12 Comments: ");
 		for (int i = 0 ; i < comments.length ; i++) 
 		    System.out.println(comments[i]);
 	    }
