@@ -1,5 +1,5 @@
 // FilenameAttribute.java
-// $Id: FilenameAttribute.java,v 1.1 1998/01/22 12:55:32 bmahe Exp $
+// $Id: FilenameAttribute.java,v 1.2 1999/09/07 13:28:53 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -20,4 +20,8 @@ public class FilenameAttribute extends StringAttribute {
 	this.type = "java.lang.String";
     }
 
+    public FilenameAttribute() {
+	super() ;
+    }
+
 }
