@@ -1,11 +1,12 @@
-// ResourceStoreManager.java
-// $Id: ResourceStoreManager.java,v 1.10.4.1 1999/12/01 14:41:14 ylafon Exp $
+// Resourcestoremanager.java
+// $Id: ResourceStoreManager.java,v 1.12 1999/12/01 14:31:12 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.resources.store ;
 
 import org.w3c.tools.resources.*;
+import org.w3c.tools.resources.serialization.Serializer;
 import org.w3c.tools.resources.event.*;
 
 import java.io.* ;
@@ -162,8 +163,9 @@ class StoreEntry implements LRUAble, Serializable {
      */
     synchronized ResourceStore getStore() {
 	if ( store == null ) {
-	    store = new SimpleResourceStore() ;
-	    store.initialize(manager, this, getRepository()) ;
+	    store = new ResourceStoreImpl() ;
+	    store.initialize(manager, this, getRepository(), 
+			     manager.serializer) ;
 	    manager.incrLoadedStore();
 	}
 	return store;
@@ -409,21 +411,19 @@ class StoreManagerSweeper extends Thread {
 }
 
 public class ResourceStoreManager implements ResourceSpace {
-
     /**
-     * The identifier for resource store files.
-     * All files that are used as resource store, and whose resource store 
-     * implementation make use of <code>pickleProlog</code> will start
-     * with a dump of that integer.
-     * @see #pickleProlog
-     * @see #unpickleProlog
+     * Number of sub-levels file system directories in the store directory.
      */
-    public static final int STOREFILE_IDENTIFIER = 0x7afeefac;
+    public final static int SUBDIRS = 128;
 
-    public static final String root_rep = "root.idx";
+    public static final String ROOT_REP = "root.xml";
+
+    public static final String STATE_F = "state.xml";
 
     public boolean debugMemory = false;
 
+    protected Serializer serializer = null;
+
     /**
      * The loaded resource stores entries.
      */
@@ -506,8 +506,8 @@ public class ResourceStoreManager implements ResourceSpace {
      * it, and the entry shutdown will have to be performed by the caller.
      * @return An StoreEntry instance, to be cleaned up.
      */
-    protected synchronized StoreEntry pickLRUEntry() {
-	return (StoreEntry) lru.removeTail();
+    protected synchronized NewStoreEntry pickLRUEntry() {
+	return (NewStoreEntry) lru.removeTail();
     }
 
     /**
@@ -517,8 +517,8 @@ public class ResourceStoreManager implements ResourceSpace {
 	if (debugMemory)
 	    System.out.println("[MEMORY] start sweeper <- "+
 			       loadedStore+" stores loaded.");
-	StoreEntry watchdog = null;
-	StoreEntry entry    = null;
+	NewStoreEntry watchdog = null;
+	NewStoreEntry entry    = null;
 	while ( loadedStore > getMaxLoadedStore() ) {
 	    entry = pickLRUEntry();
 	    if (( entry != null ) && (entry != watchdog)) {
@@ -546,19 +546,39 @@ public class ResourceStoreManager implements ResourceSpace {
      * itself from the physical location of the repository.
      * @return A fresh resource store key, guaranteed to be uniq.
      */
-    public String createResourceStoreRepository() {
-	return "st-" + state.getNextKey();
+    public synchronized String createResourceStoreRepository() {
+	int key = state.getNextKey();
+	return (key%SUBDIRS)+"/st-" + key;
     }
-  
+
     public int getCurrentStoreIdentifier() {
 	return state.getCurrentKey();
     }
 
+    protected boolean checkSubDirs() {
+	for (int i = 0 ; i < SUBDIRS ; i++) {
+	    File subd = new File(storedir, Integer.toString(i));
+	    if ((! subd.exists()) && ! subd.mkdirs())
+		return false;
+	}
+	return true;
+    }
+
     /**
      * Get the index file.
      * @return A File instance.
      */
     protected File getIndexFile() {
+	if (index == null)
+	    index = new File(storedir,server_name+"-index.xml");
+	return index;
+    }
+
+    /**
+     * Get the index file.
+     * @return A File instance.
+     */
+    protected File getOldIndexFile() {
 	if (index == null)
 	    index = new File(storedir,server_name+"-index");
 	return index;
@@ -570,7 +590,7 @@ public class ResourceStoreManager implements ResourceSpace {
      */
     protected File getRootRepository() {
 	if (root_repository == null)
-	    root_repository = new File(storedir,root_rep);
+	    root_repository = new File(storedir,ROOT_REP);
 	return root_repository;
     }
 
@@ -592,32 +612,31 @@ public class ResourceStoreManager implements ResourceSpace {
 	System.out.println("***************************");
     }
 
-    /**
-     * Save the index file.
-     */
-    protected synchronized void saveEntriesIndex() {
+    protected synchronized void saveNewEntriesIndex() {
 	File   indexFile = getIndexFile();
 	String dir       = indexFile.getParent();
 	String name      = indexFile.getName();
 	File   tmp       = new File(dir, name+".tmp");
 	File   bak       = new File(dir, name+".bak");
 	File   tild      = new File(dir, name+".bak~");
-	
-	ObjectOutputStream oo = null;
+
+	Enumeration elements = entries.elements();
+	Vector v = new Vector(10);
+	while (elements.hasMoreElements()) {
+	    NewStoreEntry entry = (NewStoreEntry) elements.nextElement();
+	    if (! entry.isTransient())
+		v.addElement(entry);
+	}
+	NewStoreEntry se[] = new NewStoreEntry[v.size()];
+	v.copyInto(se);
+
 	try {
-	    oo = new ObjectOutputStream (new BufferedOutputStream
-					 (new FileOutputStream
-					  (tmp)));
-	    oo.writeObject(entries);
-	} catch (IOException ex) {
+	    Writer writer = new BufferedWriter(new FileWriter(tmp));
+	    serializer.writeResources(se, writer);
+	} catch (Exception ex) {
 	    ex.printStackTrace();
-	    throw new RuntimeException("Unable to save entries index");
-	} finally {
-	    if (oo != null) {
-		try { oo.close(); } catch (Exception ex) {}
-	    }
+	    throw new RuntimeException("Unable to save entries index");	    
 	}
-	
 	// 1st move: delete the ~ file if any:
 	if ( tild.exists() )
 	    tild.delete() ;
@@ -644,10 +663,7 @@ public class ResourceStoreManager implements ResourceSpace {
 	tild.delete() ;
     }
 
-    /**
-     * Load the index file.
-     */
-    protected synchronized void loadEntriesIndex() {
+    protected synchronized void loadNewEntriesIndex() {
 	File indexFile = getIndexFile();
 	if (! indexFile.exists()) {
 	    File bak = new File(indexFile.getParent(), 
@@ -664,12 +680,57 @@ public class ResourceStoreManager implements ResourceSpace {
 		return;
 	    }
 	}
+	entries = new Hashtable();
+	try {
+	    Reader reader = new BufferedReader(new FileReader(indexFile));
+	    AttributeHolder holders[] = 
+		serializer.readAttributeHolders(reader);
+	    for (int i = 0 ; i < holders.length ; i++) {
+		NewStoreEntry entry = (NewStoreEntry) holders[i];
+		entries.put(entry.getKey(), entry);
+		lru.toHead((LRUAble) entry);
+		entry.initialize(this);
+	    }
+	} catch (Exception ex) {
+	    ex.printStackTrace();
+	    throw new RuntimeException("Unable to load entries index");
+	}
+    }
+
+
+    /**
+     * update the old index file. Load it and save it with the serializer.
+     * @param the index file (serialized hashtable of StoreEntry)
+     */
+    public static synchronized 
+	void updateEntriesIndex(File oldIndexFile,
+				File newIndexFile,
+				Serializer serializer) 
+	throws IOException
+    {
+	Hashtable entries = new Hashtable();
+	if (! oldIndexFile.exists()) {
+	    File bak = new File(oldIndexFile.getParent(), 
+				oldIndexFile.getName()+".bak");
+	    if (bak.exists()) {
+		System.out.println(oldIndexFile.getAbsolutePath()+
+				   " not found! using bak file :"+bak);
+		if ( !bak.renameTo(oldIndexFile) ) {
+		    System.out.println("unable to rename "+bak+" to "+
+				       oldIndexFile+
+		    "\n Try by yourself or all your resources will be lost!");
+		    System.exit(-1);
+		}
+	    } else {
+		return;
+	    }
+	}
 
 	ObjectInputStream oi = null;
 	try {
 	    oi = new ObjectInputStream(new BufferedInputStream
 				       (new FileInputStream
-					(indexFile)));
+					(oldIndexFile)));
 	    entries = (Hashtable) oi.readObject();
 	} catch (ClassNotFoundException ex) {
 	    ex.printStackTrace();
@@ -683,43 +744,63 @@ public class ResourceStoreManager implements ResourceSpace {
 	    }
 	}
 	
-	Enumeration e = entries.elements();
+	Enumeration e   = entries.elements();
+	int         len = 0;
 	while (e.hasMoreElements()) {
 	    StoreEntry entry = (StoreEntry)e.nextElement();
 	    if (entry.isTransient()) 
 		entries.remove(entry.key);
 	    else {
-		lru.toHead((LRUAble) entry);
-		entry.initialize(this);
+		len++;
+		String rep = entry.repository;
+		if (rep != null) {
+		    if (rep.equals("root.idx")) {
+			entry.repository = "root.xml";
+		    } else {
+			// st-xxx
+			int number = Integer.parseInt(rep.substring(3));
+			entry.repository = (number%SUBDIRS)+"/"+rep;
+		    }
+		}
 	    }
 	}
+	//StoreEntry => NewStoreEntry
+	e = entries.elements();
+	NewStoreEntry nentries[] = new NewStoreEntry[len];
+	int i = 0;
+	while (e.hasMoreElements()) {
+	    StoreEntry    entry  = (StoreEntry)e.nextElement();
+	    NewStoreEntry nentry = new NewStoreEntry(null,
+						     entry.repository,
+						     entry.key);
+	    nentries[i++] = nentry;
+	}
+	Writer writer = new BufferedWriter(new FileWriter(newIndexFile));
+	serializer.writeResources(nentries, writer);
     }
 
-
     /**
      * Shutdown this resource store manager.
      * Go through all entries, and shut them down.
      */
     public synchronized void shutdown() {
-	saveEntriesIndex();
+	saveNewEntriesIndex();
 	// Kill the sweeper thread:
 	sweeper.shutdown() ;
 	// Clenup all pending resource stores:
 	Enumeration enum = entries.elements() ;
 	while ( enum.hasMoreElements() ) {
-	    StoreEntry entry = (StoreEntry) enum.nextElement() ;
+	    NewStoreEntry entry = (NewStoreEntry) enum.nextElement() ;
 	    entry.shutdownStore() ;
-	    entries.remove(entry.key) ;
+	    entries.remove(entry.getKey()) ;
 	}
 	closed = true ;
 	// Now save our state:
-	File rmstate = new File(storedir, "state");
+	File rmstate = new File(storedir, STATE_F);
 	try {
-	    DataOutputStream out = (new DataOutputStream
-				    (new BufferedOutputStream
-				     (new FileOutputStream (rmstate))));
-	    state.pickle(out);
-	    out.close();
+	    Writer writer = new BufferedWriter ( new FileWriter( rmstate));
+	    AttributeHolder statearray[] = { state };
+	    serializer.writeResources(statearray, writer);
 	} catch (Exception ex) {
 	    // FIXME !!
 	    System.out.println("ResourceStoreManager: unable to save state !");
@@ -731,21 +812,19 @@ public class ResourceStoreManager implements ResourceSpace {
      * Checkpoint all modified resource stores, by saving them to disk.
      */
     public void checkpoint() {
-	saveEntriesIndex();
+	saveNewEntriesIndex();
 	// Checkpoint all loaded resource stores:
 	Enumeration e = entries.elements();
 	while ( e.hasMoreElements() ) {
-	    StoreEntry entry = (StoreEntry) e.nextElement();
+	    NewStoreEntry entry = (NewStoreEntry) e.nextElement();
 	    entry.saveStore();
 	}
 	// Then save our state:
-	File rmstate = new File(storedir, "state");
+	File rmstate = new File(storedir, STATE_F);
 	try {
-	    DataOutputStream out = (new DataOutputStream
-				    (new BufferedOutputStream
-				     (new FileOutputStream (rmstate))));
-	    state.pickle(out);
-	    out.close();
+	    Writer writer = new BufferedWriter ( new FileWriter( rmstate));
+	    AttributeHolder statearray[] = { state };
+	    serializer.writeResources(statearray, writer);
 	} catch (Exception ex) {
 	    // FIXME !!
 	    System.out.println("ResourceStoreManager: unable to save state !");
@@ -759,80 +838,17 @@ public class ResourceStoreManager implements ResourceSpace {
      * it initialized the store.
      */
     public void markUsed(Object token) {
-	StoreEntry entry = (StoreEntry) token;
+	NewStoreEntry entry = (NewStoreEntry) token;
 	if ( entry != null )
 	    lru.toHead(entry);
     }
   
-    /**
-     * Dump a prolog in given stream for that resource store.
-     * Using the resource store manager prolog in a resource store 
-     * implementation is optional. However, it is recommended that whenever 
-     * possible, you use it to get the benefits of the main method of that
-     * class.
-     * @param out The output stream to dump the prolog to.
-     * @param store The resource store which is being dumped.
-     * @exception IOException If the prolog couldn't be pickled to the
-     * given output stream.
-     * @see #unpickleProlog
-     */
-  
-    public static void pickleProlog(DataOutputStream out, ResourceStore store)
-	throws IOException
-    {
-	out.writeInt(STOREFILE_IDENTIFIER);
-	out.writeUTF(store.getClass().getName());
-	out.writeInt(store.getVersion());
-    }
-
-    /**
-     * Read in the prolog from the given input stream.
-     * This method checks the consistency between the implementation of the
-     * store that wants to read from that stream, and the implementation of
-     * the store that has been used to create it.
-     * <p>Using that method, as well as using the <code>pickleProlog</code>
-     * method is optional; however, using one makes using the other 
-     * mandatory.
-     * @param in The input stream to read the prolog from.
-     * @param store The store that is to be created from the given input 
-     * stream.
-     * @exception IOException If the stream couldn't be read.
-     * @exception NotAStoreException If the given repository wasn't flagged as
-     * containing a resource store.
-     * @exception InvalidStoreClassException If the loading class is not
-     * the saving class.
-     * @exception StoreClassVersionException If the saved store version number
-     * doesn't match the loader's class version number.
-     * @see #pickleProlog
-     */
-    public static void unpickleProlog(DataInputStream in,
-				      ResourceStore store) 
-	throws IOException,
-	       NotAStoreException, 
-	       InvalidStoreClassException,
-	       StoreClassVersionException
-    {
-	int id = in.readInt();
-	if ( id != STOREFILE_IDENTIFIER ) 
-	    // We are really in a bad situation:
-	    throw new NotAStoreException("not a store");
-	String clsname = in.readUTF();
-	int    version = in.readInt();
-	if ( ! store.getClass().getName().equals(clsname) ) 
-	    throw new InvalidStoreClassException(store.getClass().getName(),
-						 clsname);
-	if ( version != store.getVersion() ) 
-	    throw new StoreClassVersionException(store.getVersion(),
-						 version);
-	return;
-    }
-
     protected boolean used(String rep) {
 	Enumeration e = entries.elements();
-	StoreEntry entry = null;
+	NewStoreEntry entry = null;
 	while (e.hasMoreElements()) {
-	    entry = (StoreEntry)e.nextElement();
-	    System.out.println(storedir+":"+entry.repository);
+	    entry = (NewStoreEntry)e.nextElement();
+	    System.out.println(storedir+":"+entry.getRepository());
 	    try {
 		if (entry.getRepository().getName().equals(rep))
 		    return true;
@@ -864,14 +880,15 @@ public class ResourceStoreManager implements ResourceSpace {
 
     public void displayIndex() {
 	Enumeration e = entries.elements();
-	StoreEntry entry = null;
+	NewStoreEntry entry = null;
 	System.out.println("Index : ");
 	while (e.hasMoreElements()) {
-	    entry = (StoreEntry)e.nextElement();
-	    System.out.println(entry.key+" : "+entry.repository);
+	    entry = (NewStoreEntry)e.nextElement();
+	    System.out.println(entry.getKey()+" : "+entry.getRepository());
 	}
     }
     
+    
     /**
      * Try to salvage the resource store manager state.
      * That's pretty easy and robust, it should really work well if no
@@ -880,21 +897,20 @@ public class ResourceStoreManager implements ResourceSpace {
      */
     public ResourceStoreState salvageState() {
 	System.err.println("*** salvaging resource manager state...");
-	File state = new File(storedir, "state");
+	File state = new File(storedir, STATE_F);
 	int  maxid = -1;
-	// List all available stores in the directory:
-	String stores[] = storedir.list();
-	if ( stores != null ) {
-	    for (int i = 0 ; i < stores.length; i++) {
-		if ((stores[i].length() <= 3) || ! stores[i].startsWith("st-"))
-		    continue;
-		if ( stores[i].endsWith(".bak") )
-		    continue;
-		try {
-		    int id = Integer.parseInt(stores[i].substring(3));
+	FilenameFilter filter = new FilenameFilter() {
+	    public boolean accept(File dir, String name) {
+		return (name.startsWith("st-") && (! name.endsWith(".bak")));
+	    }
+	};
+	for (int i = 0 ; i < SUBDIRS ; i++) {
+	    File subdir = new File(storedir, Integer.toString(i));
+	    if (subdir.exists()) {
+		String stores[] = subdir.list(filter);
+		for (int j = 0 ; j < stores.length; j++) {
+		    int id = Integer.parseInt(stores[j].substring(3));
 		    maxid  = Math.max(maxid, id);
-		} catch (Exception ex) {
-		    ex.printStackTrace();
 		}
 	    }
 	}
@@ -904,16 +920,16 @@ public class ResourceStoreManager implements ResourceSpace {
     }
 
     /**
-     * Restore the resource whose name is given from the root StoreEntry.
+     * Restore the resource whose name is given from the root NewStoreEntry.
      * @param identifier The identifier of the resource to restore.
      * @param defs Default attribute values.
      */ 
     public ResourceReference loadRootResource(String identifier,
 					      Hashtable defs)
     {
-	StoreEntry entry = (StoreEntry) entries.get(getRootKey());
+	NewStoreEntry entry = (NewStoreEntry) entries.get(getRootKey());
 	if (entry == null) {
-	    entry = new StoreEntry(this, root_rep, getRootKey());
+	    entry = new NewStoreEntry(this, ROOT_REP, getRootKey());
 	    entries.put(getRootKey(), entry);
 	}
 	return entry.loadResource(identifier, defs);
@@ -929,7 +945,8 @@ public class ResourceStoreManager implements ResourceSpace {
     public ResourceReference lookupResource(SpaceEntry sentry, 
 					    String identifier)
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to lookup resource ("+
 				       identifier+
@@ -947,7 +964,8 @@ public class ResourceStoreManager implements ResourceSpace {
 					  String identifier,
 					  Hashtable defs)
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null) 
 	    throw new RuntimeException(identifier+": Space Entry not valid");
 	return entry.loadResource(identifier, defs);
@@ -963,7 +981,8 @@ public class ResourceStoreManager implements ResourceSpace {
 					 Resource resource,
 					 Hashtable defs)
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to add resource ("+
 				       resource.getIdentifier()+
@@ -979,7 +998,8 @@ public class ResourceStoreManager implements ResourceSpace {
     public void saveResource(SpaceEntry sentry,
 			     Resource resource) 
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to save resource ("+
 				       resource.getIdentifier()+
@@ -995,7 +1015,8 @@ public class ResourceStoreManager implements ResourceSpace {
     public void markModified(SpaceEntry sentry,
 			     Resource resource) 
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to mark resource ("+
 				       resource.getIdentifier()+
@@ -1015,7 +1036,8 @@ public class ResourceStoreManager implements ResourceSpace {
 			       String oldid,
 			       String newid) 
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to rename resource ("+
 				       oldid+" to "+newid+
@@ -1031,7 +1053,8 @@ public class ResourceStoreManager implements ResourceSpace {
     public void deleteResource(SpaceEntry sentry,
 			       Resource resource) 
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException("Unable to delete resource ("+
 				       resource.getIdentifier()+
@@ -1045,7 +1068,8 @@ public class ResourceStoreManager implements ResourceSpace {
      * @param sentry The resource space entry
      */
     public void deleteChildren(SpaceEntry sentry) {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException(
 				    "Unable to delete children, no StoreEntry"+
@@ -1060,7 +1084,8 @@ public class ResourceStoreManager implements ResourceSpace {
      * @param sentry The resource space entry
      */  
     public void saveChildren(SpaceEntry sentry) {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException(
 				      "Unable to save children, no StoreEntry"+
@@ -1084,11 +1109,12 @@ public class ResourceStoreManager implements ResourceSpace {
 				File repository,
 				boolean transientFlag) 
     {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null) {
 	    //create it.
 	    checkMaxLoadedStore();
-	    entry = new StoreEntry(this, repository, sentry.getEntryKey());
+	    entry = new NewStoreEntry(this, repository, sentry.getEntryKey());
 	    entry.setTransient(transientFlag);
 	    entries.put(sentry.getEntryKey(), entry);
 	    // FIXME : unload index hashtable ?
@@ -1103,7 +1129,8 @@ public class ResourceStoreManager implements ResourceSpace {
      */
     public void acquireChildren(SpaceEntry sentry) {
 	// 
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null) {
 	    //create it.
 	    checkMaxLoadedStore();
@@ -1123,7 +1150,7 @@ public class ResourceStoreManager implements ResourceSpace {
 		    warning("repositories "+fpath+" to "+
 			    lpath+" exists! using "+rpath);
 	    }
-	    entry = new StoreEntry(this, rpath, sentry.getEntryKey());
+	    entry = new NewStoreEntry(this, rpath, sentry.getEntryKey());
 	    entries.put(sentry.getEntryKey(), entry);
 	    // FIXME : unload index hashtable ?
 	}
@@ -1137,7 +1164,8 @@ public class ResourceStoreManager implements ResourceSpace {
      * the name of the child, as a String.
      */
     public Enumeration enumerateResourceIdentifiers(SpaceEntry sentry) {
-	StoreEntry entry = (StoreEntry) entries.get(sentry.getEntryKey());
+	NewStoreEntry entry = 
+	    (NewStoreEntry) entries.get(sentry.getEntryKey());
 	if (entry == null)
 	    throw new RuntimeException(
 				      "Unable to list children, no StoreEntry"+
@@ -1155,6 +1183,7 @@ public class ResourceStoreManager implements ResourceSpace {
 				 File storedir, 
 				 String default_root_class,
 				 String default_root_name,
+				 String serializer_class,
 				 int max_loaded_store,
 				 Hashtable defs)
     {
@@ -1167,8 +1196,21 @@ public class ResourceStoreManager implements ResourceSpace {
 	this.maxLoadedStore = (max_loaded_store < 10? 10 : max_loaded_store);
 	this.loadedStore = 0;
 	
-	loadEntriesIndex();
-	
+	try {
+	    Class ser_class = Class.forName(serializer_class);
+	    this.serializer = (Serializer) ser_class.newInstance();
+	} catch (Exception ex) {
+	    ex.printStackTrace();
+	    throw new RuntimeException("Invalid serializer class : "+
+				       serializer_class);
+	}
+
+	loadNewEntriesIndex();
+
+	if (! checkSubDirs())
+	    throw new RuntimeException("Unable to create store "+
+				       "subdirectories!");
+
 	// If not already available, create the root resource, and its
 	// repository.
 	getRootRepository();
@@ -1182,16 +1224,16 @@ public class ResourceStoreManager implements ResourceSpace {
 		defs.put("key", getRootKey());
 		root.initialize(defs);
 		
-		StoreEntry entry = new StoreEntry(this,
-						  root_rep,
-						  getRootKey());
+		NewStoreEntry entry = new NewStoreEntry(this,
+							ROOT_REP,
+							getRootKey());
 		ResourceReference rr = entry.addResource(root, defs);
 		ResourceContext context = (ResourceContext) 
 		    defs.get("context");
 		context.setResourceReference(rr);
 		entry.saveResource(root);
 		entries.put(getRootKey(), entry);
-		saveEntriesIndex();
+		saveNewEntriesIndex();
 	    } catch (InstantiationException ex) {
 	    } catch (IllegalAccessException ex) {
 	    } catch (ClassNotFoundException ex) {
@@ -1201,20 +1243,19 @@ public class ResourceStoreManager implements ResourceSpace {
 	}
 	
 	// If not already available, create the resource store state object:
-	File rsmstate = new File(storedir, "state");
+	File rsmstate = new File(storedir, STATE_F);
 	// Restore it:
-	DataInputStream in = null;
+	Reader reader = null;
 	try {
-	    in = (new DataInputStream
-		  (new BufferedInputStream 
-		   (new FileInputStream(rsmstate))));
-	    this.state = (ResourceStoreState) AttributeHolder.unpickle(in);
+	    reader = new BufferedReader( new FileReader(rsmstate));
+	    AttributeHolder states[] = serializer.readAttributeHolders(reader);
+	    this.state = (ResourceStoreState) states[0];
 	} catch (Exception ex) {
 	    // Let's try to fix this:
 	    this.state = salvageState();
 	}
-	if ( in != null ) {
-	    try { in.close(); } catch (IOException ex) {}
+	if ( reader != null ) {
+	    try { reader.close(); } catch (IOException ex) {}
 	}
 	//    salvage();
 	//    displayIndex();
